@@ -92,9 +92,15 @@ RESOURCENOTFOUND_MEMBERNOTEXIST = 'ResourceNotFound.MemberNotExist'
 # 组织成员策略不存在。
 RESOURCENOTFOUND_MEMBERPOLICYNOTEXIST = 'ResourceNotFound.MemberPolicyNotExist'
 
+# 组织节点不在。
+RESOURCENOTFOUND_ORGANIZATIONNODENOTEXIST = 'ResourceNotFound.OrganizationNodeNotExist'
+
 # 企业组织不存在。
 RESOURCENOTFOUND_ORGANIZATIONNOTEXIST = 'ResourceNotFound.OrganizationNotExist'
 
+# 集团服务不存在。
+RESOURCENOTFOUND_ORGANIZATIONSERVICENOTEXIST = 'ResourceNotFound.OrganizationServiceNotExist'
+
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
